Crate normal_heights
normal_
heights
0.1.2
All Items
Crate Items
Constants
Functions
Crate
normal_
heights
Constants

DEFAULT_
STRENGTH
Functions

map_
normals
Creates the normal mapping from the given image with
DEFAULT_STRENGTH
map_
normals_
with_
strength
Creates the normal mapping from the given image with the given strength.