pub fn map_normals(img: &DynamicImage) -> RgbImageExpand description
Creates the normal mapping from the given image with DEFAULT_STRENGTH
pub fn map_normals(img: &DynamicImage) -> RgbImageCreates the normal mapping from the given image with DEFAULT_STRENGTH